==> openmolcas_19.11.orig.tar.gz: OpenMolcas-v19.11/CONTRIBUTORS.md <==
OpenMolcas
==========

OpenMolcas is free software: you can redistribute it and/or modify it
under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, version 2.1.

OpenMolcas is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with OpenMolcas. If not, see <http://www.gnu.org/licenses/>.

Copyright (C) 1989-2019, The OpenMolcas Authors


NOTE: Some of the files distributed with OpenMolcas may be subject to a more
permissive or otherwise compatible license. Some of the files from external
sources may be subject to a more restrictive or otherwise incompatible license.


General citations
=================

* **OpenMolcas**:
  *J. Chem. Theory Comput.* **15** (2019) 5925-5964. DOI: [10.1021/acs.jctc.9b00532](https://doi.org/10.1021/acs.jctc.9b00532)

* **Molcas 8**:
  *J. Comput. Chem.* **37** (2016) 506-541. DOI: [10.1002/jcc.24221](https://doi.org/10.1002/jcc.24221)

* **Molcas 7**:
  *J. Comput. Chem.* **31** (2010) 224-247. DOI: [10.1002/jcc.21318](https://doi.org/10.1002/jcc.21318)

* **Molcas 6**:
  *Comput. Mat. Sci.* **28** (2003) 222-239. DOI: [10.1016/S0927-0256(03)00109-5](https://doi.org/10.1016/S0927-0256(03)00109-5)

* **Code development**:
  *Wiley Interdiscip. Rev. Comput. Mol. Sci.* **3** (2013) 143-149. DOI: [10.1002/wcms.1117](https://doi.org/10.1002/wcms.1117);
  *Int. J. Quantum Chem.* **100** (2004) 626-635. DOI: [10.1002/qua.20166](https://doi.org/10.1002/qua.20166)


Contributors
============

The following is a list of people who have contributed at some point to the
code of OpenMolcas. They are hereby acknowledged and collectively identified as
"The OpenMolcas Authors".

Christian Ander  
Kerstin Andersson  
János G. Ángyán  
Francesco Aquilante  
Jochen Autschbach  
Jie J. Bao  
Maria Barysz  
Stefano Battaglia  
Eugeniusz Bednarz  
Nelson H. F. Beebe  
Anders Bernhardsson  
Margareta R. A. Blomberg  
Piotr Borowski  
Jonas Boström  
Per Boussard  
John Burkardt  
Yannick Carissan  
Liviu Chibotaru  
Christophe Chipot  
Aron Cohen  
David L. Cooper  
Maurizio Cossi  
Joel Creutzberg  
Oleh Danyliv  
Mickaël G. Delcey  
Ajitha Devarajan  
Luca De Vico  
Michael Diedenhofen  
Sijia S. Dong  
Thomas Dresselhaus  
Daniel Fairhead  
Ignacio Fdez. Galván  
Nicolas Ferré  
Timo Fleig  
Leon Freitag  
Luis Manuel Frutos  
Markus P. Fülscher  
Alexander Gaenko  
Laura Gagliardi  
Walter Gautschi  
Giovanni Ghigo  
Coen de Graaf  
Gene H. Golub  
Sergey Gusarov  
Daniel Hagberg  
Jun-ya Hasegawa  
José Manuel Hermida-Ramón  
Bernd Artur Heß  
Asbjørn Holt  
Chad E. Hoyer  
Denis Jelovina  
Marcus Johansson  
Erik Källman  
Gunnar Karlström  
Stefan Knecht  
Jesper Wisborg Krogh  
Teodoro Laino  
Giovanni Li Manni  
Roland Lindh  
Johan Lorentzon  
Dongxia Ma  
Yingjin Ma  
Per Åke Malmqvist  
Neil Martinsen-Burrell  
Andy May  
Manuela Merchán  
Samuel Mikes  
Abdul Rehaman Moughal Shahi  
Thomas Müller  
Takahito Nakajima  
Naoki Nakatani  
Pavel Neogrády  
Jesper Norell  
Anders Öhrn  
Jeppe Olsen  
Markus Oppel  
Thomas Bondo Pedersen  
Daoling Peng  
Kurt Pfingst  
Quan Phung  
Michal Pitoňák  
Felix Plasser  
Christian Pomelli  
Ben Pritchard  
Juraj Raab  
Markus Reiher  
H. Rieger  
Björn O. Roos  
Ulf Ryde  
Pawel Salek  
Andrew M. Sand  
Michael A. Saunders  
Igor Schapiro  
Bernd Schimmelpfennig  
Martin Schütz  
Luis Seijo  
Luis Serrano-Andrés  
Kamal Sharkas  
Grigory A. Shamov  
Prachi Sharma  
Per E. M. Siegbahn  
Pär Söderhjelm  
Lasse Kragh Sørensen  
Jonna Stålring  
Hermann Stoll  
Bingbing Suo  
Ben Swerts  
Akio Takatsuka  
Thorstein Thorsteinsson  
Takashi Tsuchiya  
Liviu Ungur  
Morgane Vacher  
Alessio Valentini  
Valérie Vallet  
Steven Vancoillie  
Valera Veryazov  
Victor P. Vysotskiy  
Ulf Wahlgren  
Yubin Wang  
Mark A. Watson  
Hans-Joachim Werner  
Oskar Weser  
Per-Olof Widmark  
Małgorzata Wierzbowska  
Alexander Wolf  
Sebastian Wouters  
Felipe Zapata  
Alexander Zech  
Yan Zhao  
J. Patrick Zobel

==> openmolcas_20.10.orig.tar.gz: OpenMolcas-v20.10/CONTRIBUTORS.md <==
OpenMolcas
==========

OpenMolcas is free software: you can redistribute it and/or modify it
under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, version 2.1.

OpenMolcas is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with OpenMolcas. If not, see <http://www.gnu.org/licenses/>.

Copyright (C) 1989-2020, The OpenMolcas Authors


NOTE: Some of the files distributed with OpenMolcas may be subject to a more
permissive or otherwise compatible license. Some of the files from external
sources may be subject to a more restrictive or otherwise incompatible license.


General citations
=================

* **OpenMolcas**:
  *J. Chem. Theory Comput.* **15** (2019) 5925-5964. [doi:10.1021/acs.jctc.9b00532](https://doi.org/10.1021/acs.jctc.9b00532)

* **Molcas 8**:
  *J. Comput. Chem.* **37** (2016) 506-541. [doi:10.1002/jcc.24221](https://doi.org/10.1002/jcc.24221)

* **Molcas 7**:
  *J. Comput. Chem.* **31** (2010) 224-247. [doi:10.1002/jcc.21318](https://doi.org/10.1002/jcc.21318)

* **Molcas 6**:
  *Comput. Mat. Sci.* **28** (2003) 222-239. [doi:10.1016/S0927-0256(03)00109-5](https://doi.org/10.1016/S0927-0256(03)00109-5)

* **Code development**:
  *Wiley Interdiscip. Rev. Comput. Mol. Sci.* **3** (2013) 143-149. [doi:10.1002/wcms.1117](https://doi.org/10.1002/wcms.1117);
  *Int. J. Quantum Chem.* **100** (2004) 626-635. [doi:10.1002/qua.20166](https://doi.org/10.1002/qua.20166)


Contributors
============

The following is a list of people who have contributed at some point to the
code of OpenMolcas. They are hereby acknowledged and collectively identified as
"The OpenMolcas Authors".

Christian Ander  
Kerstin Andersson  
János G. Ángyán  
Imaad Ansari  
Francesco Aquilante  
Jochen Autschbach  
Jie J. Bao  
Maria Barysz  
Stefano Battaglia  
Eugeniusz Bednarz  
Nelson H. F. Beebe  
Anders Bernhardsson  
Margareta R. A. Blomberg  
Piotr Borowski  
Jonas Boström  
Per Boussard  
John Burkardt  
Yannick Carissan  
Liviu Chibotaru  
Christophe Chipot  
Aron Cohen  
David L. Cooper  
Maurizio Cossi  
Joel Creutzberg  
Oleh Danyliv  
Mickaël G. Delcey  
Ajitha Devarajan  
Luca De Vico  
Michael Diedenhofen  
Sijia S. Dong  
Thomas Dresselhaus  
Daniel Fairhead  
Ignacio Fdez. Galván  
Nicolas Ferré  
Timo Fleig  
Leon Freitag  
Luis Manuel Frutos  
Markus P. Fülscher  
Alexander Gaenko  
Laura Gagliardi  
Walter Gautschi  
Giovanni Ghigo  
Coen de Graaf  
Gene H. Golub  
Sergey Gusarov  
Daniel Hagberg  
Jun-ya Hasegawa  
Matthew R. Hermes  
José Manuel Hermida-Ramón  
Bernd Artur Heß  
Asbjørn Holt  
Chad E. Hoyer  
Denis Jelovina  
Marcus Johansson  
Erik Källman  
Gunnar Karlström  
Stefan Knecht  
Jesper Wisborg Krogh  
Teodoro Laino  
Giovanni Li Manni  
Roland Lindh  
Johan Lorentzon  
Dongxia Ma  
Yingjin Ma  
Per Åke Malmqvist  
Neil Martinsen-Burrell  
Andy May  
Manuela Merchán  
Samuel Mikes  
Abdul Rehaman Moughal Shahi  
Thomas Müller  
Takahito Nakajima  
Naoki Nakatani  
Pavel Neogrády  
Jesper Norell  
Anders Öhrn  
Jeppe Olsen  
Markus Oppel  
Thomas Bondo Pedersen  
Daoling Peng  
Kurt Pfingst  
Quan Phung  
Michal Pitoňák  
Felix Plasser  
Christian Pomelli  
Ben Pritchard  
Juraj Raab  
Gerardo Raggi  
Markus Reiher  
H. Rieger  
Björn O. Roos  
Ulf Ryde  
Pawel Salek  
Andrew M. Sand  
Michael A. Saunders  
Igor Schapiro  
Bernd Schimmelpfennig  
Martin Schütz  
Thais Scott  
Luis Seijo  
Luis Serrano-Andrés  
Kamal Sharkas  
Grigory A. Shamov  
Prachi Sharma  
Per E. M. Siegbahn  
Pär Söderhjelm  
Lasse Kragh Sørensen  
Jonna Stålring  
Hermann Stoll  
Bingbing Suo  
Ben Swerts  
Akio Takatsuka  
Thorstein Thorsteinsson  
Takashi Tsuchiya  
Liviu Ungur  
Morgane Vacher  
Alessio Valentini  
Valérie Vallet  
Steven Vancoillie  
Valera Veryazov  
Victor P. Vysotskiy  
Ulf Wahlgren  
Yubin Wang  
Mark A. Watson  
Hans-Joachim Werner  
Oskar Weser  
Per-Olof Widmark  
Małgorzata Wierzbowska  
Alexander Wolf  
Sebastian Wouters  
Felipe Zapata  
Alexander Zech  
Yan Zhao  
J. Patrick Zobel
